==> NlpToolkit-Dictionary-1.0.2.tar.gz: NlpToolkit-Dictionary-1.0.2/Dictionary/Trie/Trie.py <==
from Dictionary.Trie.TrieNode import TrieNode
from Dictionary.Word import Word
from Dictionary.TxtWord import TxtWord


class Trie:

    """
    A constructor of Trie class which creates a new TrieNode as rootNode.
    """
    def __init__(self):
        self.rootNode = TrieNode()

    """
    The addWord method which takes a String word and a Word root as inputs and adds given word and root to the rootNode.

    PARAMETERS
    ----------
    word : str
        String input.
    root : Word
        Word input.
    """
    def addWord(self, word : str, root : Word):
        self.rootNode.addWord(word, root)

    """
    The getWordsWithPrefix method which takes a String surfaceForm as an input. First it creates a TrieNode current and 
    assigns the rootNode to it, then it creates a new set words. It loops i times where i ranges from 0 to length of 
    surfaceForm and assigns current's child that corresponds to the surfaceForm's char at index i and assigns it as 
    TrieNode current. If current is not None, it adds all words of current to the words set.

    PARAMETERS
    ----------
    surfaceForm : str
        String input.
        
    RETURNS
    -------
    set
        words set.
    """
    def getWordsWithPrefix(self, surfaceForm : str) -> set:
        current = self.rootNode
        words = set()
        for i in range(len(surfaceForm)):
            current = current.getChild(surfaceForm[i])
            if current is not None:
                words.update(current.getWords())
            else:
                break
        return words

    """
    The getCompoundWordStartingWith method takes a String hash. First it creates a TrieNode current and assigns
    the rootNode to it. Then it loops i times where i ranges from 0 to length of given hash and assigns current's 
    child that corresponds to the hash's char at index i and assigns it as current. If current is None, it returns null.

    If current is not None, it loops through the words of current TrieNode and if it is a Portmanteau word, it
    directly returns the word.

    PARAMETERS
    ----------
    hash : str
        String input.
        
    RETURNS
    -------
    TxtWord
        None if TrieNode is None, otherwise portmanteau word.
    """
    def getCompundWordStartingWith(self, hash : str) -> TxtWord:
        current = self.rootNode
        for i in range(len(hash)):
            current = current.getChild(hash[i])
            if current is None:
                return None
        if current is not None:
            for word in current.getWords():
                if word.isPortmanteau():
                    return word
        return None

==> NlpToolkit-Dictionary-1.0.11.tar.gz: NlpToolkit-Dictionary-1.0.11/Dictionary/Trie/Trie.py <==
from Dictionary.Trie.TrieNode import TrieNode
from Dictionary.Word import Word
from Dictionary.TxtWord import TxtWord


class Trie:

    __rootNode: TrieNode

    """
    A constructor of Trie class which creates a new TrieNode as rootNode.
    """
    def __init__(self):
        self.__rootNode = TrieNode()

    """
    The addWord method which takes a String word and a Word root as inputs and adds given word and root to the rootNode.

    PARAMETERS
    ----------
    word : str
        String input.
    root : Word
        Word input.
    """
    def addWord(self, word: str, root : Word):
        self.__rootNode.addWord(word, root)

    """
    The getWordsWithPrefix method which takes a String surfaceForm as an input. First it creates a TrieNode current and 
    assigns the rootNode to it, then it creates a new set words. It loops i times where i ranges from 0 to length of 
    surfaceForm and assigns current's child that corresponds to the surfaceForm's char at index i and assigns it as 
    TrieNode current. If current is not None, it adds all words of current to the words set.

    PARAMETERS
    ----------
    surfaceForm : str
        String input.
        
    RETURNS
    -------
    set
        words set.
    """
    def getWordsWithPrefix(self, surfaceForm: str) -> set:
        current = self.__rootNode
        words = set()
        for i in range(len(surfaceForm)):
            current = current.getChild(surfaceForm[i])
            if current is not None:
                words.update(current.getWords())
            else:
                break
        return words

    """
    The getCompoundWordStartingWith method takes a String hash. First it creates a TrieNode current and assigns
    the rootNode to it. Then it loops i times where i ranges from 0 to length of given hash and assigns current's 
    child that corresponds to the hash's char at index i and assigns it as current. If current is None, it returns null.

    If current is not None, it loops through the words of current TrieNode and if it is a Portmanteau word, it
    directly returns the word.

    PARAMETERS
    ----------
    hash : str
        String input.
        
    RETURNS
    -------
    TxtWord
        None if TrieNode is None, otherwise portmanteau word.
    """
    def getCompundWordStartingWith(self, hash: str) -> TxtWord:
        current = self.__rootNode
        for i in range(len(hash)):
            current = current.getChild(hash[i])
            if current is None:
                return None
        if current is not None:
            for word in current.getWords():
                if word.isPortmanteau():
                    return word
        return None
